@@ -17,6 +17,6 @@ logger = logging.getLogger('coopr')
 logger.addHandler( NullHandler() )
 logger.setLevel( logging.WARNING )
 
-logger = logging.getLogger('coopr.plugins')
+logger = logging.getLogger('coopr.solvers')
 logger.addHandler( LogHandler(coopr_base) )
 logger.setLevel( logging.WARNING )
