@@ -10,8 +10,7 @@
 
 __all__ = [ 'IProblemWriter', 'AbstractProblemWriter', 'WriterFactory' ]
 
-from pyutilib.component.core import *
-from pyutilib.component.config import *
+from coopr.core.plugin import *
 
 
 class IProblemWriter(Interface):
@@ -19,13 +18,13 @@ class IProblemWriter(Interface):
 
 WriterFactory = CreatePluginFactory(IProblemWriter)
 
-class AbstractProblemWriter(ManagedPlugin):
+class AbstractProblemWriter(Plugin):
     """Base class that can write optimization problems."""
 
     implements(IProblemWriter)
 
     def __init__(self, problem_format): #pragma:nocover
-        ManagedPlugin.__init__(self)
+        Plugin.__init__(self)
         self.format=problem_format
 
     def __call__(self, model, filename, solver_capability, **kwds): #pragma:nocover
