@@ -15,21 +15,13 @@ from pyutilib.enum import Enum
 
 ActionStatus = Enum('done', 'error', 'queued', 'executing', 'unknown')
 
-# a simple utility to, given a solver manager and a solver, apply the solver to
-# each problem instance, load the results into the instance, and execute a barrier
-# synchronization. all keywords are passed to each invocation of the solver.
+
 def solve_all_instances(solver_manager, solver, instances, **kwds):
-    action_handles = []
-    instance_map = {}
-    kwds['opt'] = solver
-    for instance in instances:
-        action_handle = solver_manager.queue(instance, **kwds)
-        instance_map[action_handle] = instance
-        action_handles.append(action_handle)
-    solver_manager.wait_all(action_handles)
-    for action_handle in action_handles:
-        results = solver_manager.get_results(action_handle)
-        instance_map[action_handle].load(results)
+    """
+    A simple utility to apply a solver to a list of problem instances.
+    """
+    solver_manager.solve_all(solver, instances, **kwds)
+
 
 class ActionManagerError(Exception):
     """
