@@ -17,12 +17,12 @@ from coopr.opt import ProblemFormat, ConverterError
 import coopr
 import pyutilib.th as unittest
 import pyutilib.services
-import pyutilib.component.config
-import pyutilib.component.core
+import coopr.core.plugin
 import pyutilib.common
 import xml
 import filecmp
 
+old_tempdir = pyutilib.services.TempfileManager.tempdir
 
 class MockArg(object):
 
@@ -74,11 +74,13 @@ class OptConvertDebug(unittest.TestCase):
 
     def tearDown(self):
         pyutilib.services.TempfileManager.clear_tempfiles()
+        pyutilib.services.TempfileManager.tempdir = old_tempdir
         #
         # Reset all options
         #
-        for ep in pyutilib.component.core.ExtensionPoint(pyutilib.component.config.IOption):
-            ep.reset()
+        #for ep in coopr.core.plugin.ExtensionPoint(coopr.core.plugin.IOption):
+            #ep.reset()
+        pass
 
     def test_nl_nl1(self):
         """ Convert from NL to NL """
